@@ -80,9 +80,14 @@ def create_html_zip(target, commit):
         subprocess.call(['svn', 'ci', zf.filename, '-m', message])
 #        subprocess.call(['svn', 'st'])#, zf.filename])
 
+
 def unzip_html_docs(src_path, dest_dir):
     """ Given a path to a zipfile, extract its contents to a given 'dest_dir'.
     """
+    if not os.path.isfile(src_path):
+        print "Warning: source %r does not exist" % src_path
+        return
+
     file = zipfile.ZipFile(src_path)
     for name in file.namelist():
         cur_name = os.path.join(dest_dir, name)
@@ -96,6 +101,7 @@ def unzip_html_docs(src_path, dest_dir):
             out.close()
     file.close()
 
+
 def show_formats():
     DOC_FORMATS = {
         'html': (BuildDocs, [], "(default) create folder 'build/docs/html' "
@@ -209,7 +215,7 @@ class BuildDocs(Command):
                         log.error('Unable to generate %s docs.' % format)
                         if format == 'html' and len(self.formats) == 1:
                             log.info("Installing %s html documentation from zip"
-                                " file.\n" % self.distribution.get_name())
+                                     " file.\n" % self.distribution.get_name())
                             unzip_html_docs(HTML_ZIP, TARGET_DIR)
 
         else:
@@ -218,13 +224,13 @@ class BuildDocs(Command):
             elif len(self.formats) > 1:
                 # Unzip the docs into the 'html' folder.
                 log.info("Installing %s html documentation from zip file. Cannot"
-                    " generate other formats without Sphinx install.\n" \
-                    % self.name)
+                         " generate other formats without Sphinx install.\n" %
+                         self.name)
                 unzip_html_docs(HTML_ZIP, TARGET_DIR)
             else:
                 # Unzip the docs into the 'html' folder.
-                log.info("Installing %s html documentation from zip file.\n" \
-                    % self.name)
+                log.info("Installing %s html documentation from zip file.\n" %
+                         self.name)
                 unzip_html_docs(HTML_ZIP, TARGET_DIR)
 
         # Using extend so the existing data_files doesn't get replaced
